@@ -1,5 +1,5 @@
 #  Pyrogram - Telegram MTProto API Client Library for Python
-#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
+#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
 #
 #  This file is part of Pyrogram.
 #
@@ -18,13 +18,13 @@
 
 from typing import Union
 
+import pyrogram
 from pyrogram import raw
-from pyrogram.scaffold import Scaffold
 
 
-class UnpinAllChatMessages(Scaffold):
+class UnpinAllChatMessages:
     async def unpin_all_chat_messages(
-        self,
+        self: "pyrogram.Client",
         chat_id: Union[int, str],
     ) -> bool:
         """Use this method to clear the list of pinned messages in a chat.
@@ -42,9 +42,9 @@ class UnpinAllChatMessages(Scaffold):
             .. code-block:: python
 
                 # Unpin all chat messages
-                app.unpin_all_chat_messages(chat_id)
+                await app.unpin_all_chat_messages(chat_id)
         """
-        await self.send(
+        await self.invoke(
             raw.functions.messages.UnpinAllMessages(
                 peer=await self.resolve_peer(chat_id)
             )
